# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77
#
# (C) Copyright IBM Corp. 2005,2006 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
#!/usr/bin/sh
################## subroutine definitions ###############

general_syntax() {
    echo "Usage: $0 [-enable|-disable] -env [1|2|3|4|8|9] <server_specific_options>"
    echo "   Application server environments:"
    echo "      1 = IBM WebSphere Application Server"
    echo "      2 = Microsoft ASP.NET"
    echo "      3 = BEA WebLogic Application Server"
    echo "      4 = JBoss Application Server"
    echo "      8 = DataPower"
    echo "      9 = Service Component Architecture (SCA) monitoring in WESB and WPS"

    rc=100;
}

find_KD4_home() {
    KD4_CONFIG="/etc/KD4BaseDirConfig.properties"
    if [ -f "$KD4_CONFIG" ]
    then
       . $KD4_CONFIG
       if [ -d "$INSTALLDIR" ]
       then
           echo "KD4 Home Dir = $INSTALLDIR"
           export INSTALLDIR
       else
           echo "Error: $INSTALLDIR not found" 
           rc=111
       fi
    else
        echo "Error: $KD4_CONFIG not found"
        rc=111
    fi
}

call_WAS_script()
{
    if [ ! "$ACTION" ] || [ "$ARG4" = "-h" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 1 (<WAS_HOME>)"
        rc=100;
    else
        if [ ! "$ARG4" ]
        then
            ARG4="USE_ENV_VAR"
        fi

        cmd="sh $INSTALLDIR/KD4/bin/configWASDC.sh $ACTION $ARG4" 
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configWASDC.sh = $rc"
    fi
}

call_NET_script()
{
    OS=`uname`
    echo "Error:  Microsoft ASP.NET environment not supported on $OS"
    rc=114;

}

call_BEA_script()
{
    if [ ! "$ARG6" ]
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 3 <URL> <userid> <password>"
        rc=100;
    else
        cmd="sh $INSTALLDIR/KD4/bin/configBEADC.sh $ACTION $ARG4 $ARG5 $ARG6 $INSTALLDIR"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configBEADC.sh = $rc"
    fi
}

# call the configDPDC.sh script.

call_DP_script()
{
   # min args: -action -env 8 -host hostName -user userName
 
   if [ ! "$ARG7" ] 
   then
      echo "Syntax: KD4configDC [-enable | -disable] -env 8 -host hostName -user userName (-pswd password -port port -path urlPath -poll pollInterval -domainlist \"domain1,domain2,...\" -displaygroup groupName"
      rc=100;
   else

        PROP_FILE=$INSTALLDIR/KD4/config/KD4.dpdcConfig.properties;

        # pull in the rest of the keys and values (4th arg to the end)
        KEY_VALUE_ARGS=`echo $ALL_ARGS | cut -f4- -d" "`

        cmd="sh $INSTALLDIR/KD4/bin/configDPDC.sh $ACTION $INSTALLDIR $PROP_FILE $KEY_VALUE_ARGS"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configDPDC.sh = $rc"
    fi
      
}

call_SCA_script()
{
    if [ ! "$ACTION" ] || [ "$ARG4" = "-h" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 9 (<WESB_HOME> | <WPS_HOME>)"
        rc=100;
    else
        if [ ! "$ARG4" ]
        then
            ARG4="USE_ENV_VAR"
        fi

        cmd="sh $INSTALLDIR/KD4/bin/configSCADC.sh $ACTION $ARG4" 
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configSCADC.sh = $rc"
    fi
}

# call configJBOSSDC.sh script
call_JBOSS_script()
{
    if [ ! "$ARG4" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 4 <server_name> <JBOSS_HOME>"
        echo "     server_name : Name of server need to be configured"
	echo "     JBOSS_HOME : The path name where JBOSS installed into, optional. If user already exported the JBOSS_HOME into environment, it's not required. Otherwise, user must provide that when running the script."
        rc=100;
    else
    	if [ ! "$ARG5" ]
    	then 
    		echo $ARG5
    		ARG5="USE_ENV_HOME"
    		echo $ARG5
    	fi
        cmd="sh $INSTALLDIR/KD4/bin/configJBOSSDC.sh $ACTION $ARG4 $INSTALLDIR $ARG5"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configJBOSSDC.sh = $rc"
    fi
}

######################## mainline ######################
ACTION=$1
ENV_KEY=$2
ENV_TYPE=$3
ARG4=$4
ARG5=$5
ARG6=$6
ARG7=$7
ALL_ARGS=$*

rc=0;

if [ "$ENV_KEY" != "-env" ] 
then
   general_syntax 
   exit $rc
fi  

if [ "$ACTION" != "-enable" ] && [ "$ACTION" != "-disable" ]
then
   general_syntax 
   exit $rc
fi  


find_KD4_home

case $ENV_TYPE in
    1) call_WAS_script ;;
    2) call_NET_script ;;
    3) call_BEA_script ;;
    4) call_JBOSS_script ;;
    8) call_DP_script ;;
    9) call_SCA_script ;;
    *) general_syntax ;;
esac

exit $rc;
